Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1108)

Unified Diff: mojo/dart/test/handle_finalizer_test.dart

Issue 1414483010: Dart: Use a RawReceivePort to receive events for Mojo handles. (Closed) Base URL: git@github.com:domokit/mojo.git@master
Patch Set: Merge Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: mojo/dart/test/handle_finalizer_test.dart
diff --git a/mojo/dart/test/handle_finalizer_test.dart b/mojo/dart/test/handle_finalizer_test.dart
index 39a1522ffbb4fe7c9215ccc8b1d3ced4f4d1ec22..171e7d5811b877d8451ee77eb2e0420b27852a00 100644
--- a/mojo/dart/test/handle_finalizer_test.dart
+++ b/mojo/dart/test/handle_finalizer_test.dart
@@ -16,9 +16,9 @@ MojoHandle leakMojoHandle() {
var endpoint = pipe.endpoints[0];
Expect.isTrue(endpoint.handle.isValid);
- var eventStream = new MojoEventStream(endpoint.handle);
- // After making a MojoEventStream, the underlying mojo handle will have
- // the native MojoClose called on it when the MojoEventStream is GC'd or the
+ var eventHandler = new MojoEventHandler(endpoint.handle);
+ // After making a MojoEventHandler, the underlying mojo handle will have
+ // the native MojoClose called on it when the MojoEventHandler is GC'd or the
// VM shuts down.
return endpoint.handle;

Powered by Google App Engine
This is Rietveld 408576698